aboutsummaryrefslogtreecommitdiffstats
path: root/storage
diff options
context:
space:
mode:
authorGeir Storli <geirst@verizonmedia.com>2021-03-22 13:28:29 +0000
committerGeir Storli <geirst@verizonmedia.com>2021-03-22 13:28:29 +0000
commitcb4236502fb0fefbb86654f0a8252def90b15bc0 (patch)
tree8fe8f6426c40932bc8bf729e801e3c9fe3ce9aee /storage
parent1dfa0e9d42d47f375c8b6a4db457cba862e6b20b (diff)
Rename DistributorComponent -> DistributorStripeComponent.
Diffstat (limited to 'storage')
-rw-r--r--storage/src/tests/distributor/distributortestutil.cpp6
-rw-r--r--storage/src/tests/distributor/distributortestutil.h4
-rw-r--r--storage/src/vespa/storage/common/distributorcomponent.h2
-rw-r--r--storage/src/vespa/storage/distributor/CMakeLists.txt12
-rw-r--r--storage/src/vespa/storage/distributor/bucketdbupdater.h14
-rw-r--r--storage/src/vespa/storage/distributor/distributor.cpp6
-rw-r--r--storage/src/vespa/storage/distributor/distributor.h6
-rw-r--r--storage/src/vespa/storage/distributor/distributor_stripe.cpp2
-rw-r--r--storage/src/vespa/storage/distributor/distributor_stripe.h4
-rw-r--r--storage/src/vespa/storage/distributor/distributor_stripe_component.cpp (renamed from storage/src/vespa/storage/distributor/distributorcomponent.cpp)40
-rw-r--r--storage/src/vespa/storage/distributor/distributor_stripe_component.h (renamed from storage/src/vespa/storage/distributor/distributorcomponent.h)21
-rw-r--r--storage/src/vespa/storage/distributor/externaloperationhandler.h2
-rw-r--r--storage/src/vespa/storage/distributor/idealstatemanager.h8
-rw-r--r--storage/src/vespa/storage/distributor/operations/external/statbucketoperation.cpp2
-rw-r--r--storage/src/vespa/storage/distributor/persistencemessagetracker.h2
-rw-r--r--storage/src/vespa/storage/distributor/statechecker.cpp4
-rw-r--r--storage/src/vespa/storage/distributor/statechecker.h6
17 files changed, 71 insertions, 70 deletions
diff --git a/storage/src/tests/distributor/distributortestutil.cpp b/storage/src/tests/distributor/distributortestutil.cpp
index b465edf5d16..5d7a61692f6 100644
--- a/storage/src/tests/distributor/distributortestutil.cpp
+++ b/storage/src/tests/distributor/distributortestutil.cpp
@@ -4,9 +4,9 @@
#include <vespa/document/test/make_bucket_space.h>
#include <vespa/document/test/make_document_bucket.h>
#include <vespa/storage/distributor/distributor.h>
-#include <vespa/storage/distributor/distributor_stripe.h>
#include <vespa/storage/distributor/distributor_bucket_space.h>
-#include <vespa/storage/distributor/distributorcomponent.h>
+#include <vespa/storage/distributor/distributor_stripe.h>
+#include <vespa/storage/distributor/distributor_stripe_component.h>
#include <vespa/vdslib/distribution/distribution.h>
#include <vespa/vespalib/text/stringtokenizer.h>
@@ -351,7 +351,7 @@ DistributorTestUtil::getExternalOperationHandler() {
return _distributor->external_operation_handler();
}
-storage::distributor::DistributorComponent&
+storage::distributor::DistributorStripeComponent&
DistributorTestUtil::distributor_component() {
// TODO STRIPE tests use this to indirectly access bucket space repos/DBs!
return _distributor->distributor_component();
diff --git a/storage/src/tests/distributor/distributortestutil.h b/storage/src/tests/distributor/distributortestutil.h
index f450f2545db..809a87d3bb7 100644
--- a/storage/src/tests/distributor/distributortestutil.h
+++ b/storage/src/tests/distributor/distributortestutil.h
@@ -21,7 +21,7 @@ class BucketDBUpdater;
class Distributor;
class DistributorBucketSpace;
class DistributorBucketSpaceRepo;
-class DistributorComponent;
+class DistributorStripeComponent;
class DistributorStripe;
class IdealStateManager;
class ExternalOperationHandler;
@@ -114,7 +114,7 @@ public:
BucketDBUpdater& getBucketDBUpdater();
IdealStateManager& getIdealStateManager();
ExternalOperationHandler& getExternalOperationHandler();
- storage::distributor::DistributorComponent& distributor_component();
+ storage::distributor::DistributorStripeComponent& distributor_component();
Distributor& getDistributor() {
return *_distributor;
diff --git a/storage/src/vespa/storage/common/distributorcomponent.h b/storage/src/vespa/storage/common/distributorcomponent.h
index 27680b8c6ce..8d5920ecc77 100644
--- a/storage/src/vespa/storage/common/distributorcomponent.h
+++ b/storage/src/vespa/storage/common/distributorcomponent.h
@@ -1,6 +1,6 @@
// Copyright 2017 Yahoo Holdings. Licensed under the terms of the Apache 2.0 license. See LICENSE in the project root.
/**
- * \class storage::DistributorComponent
+ * \class storage::DistributorStripeComponent
* \ingroup common
*
* \brief Component class including some service layer specific information.
diff --git a/storage/src/vespa/storage/distributor/CMakeLists.txt b/storage/src/vespa/storage/distributor/CMakeLists.txt
index 2b5423c60e4..d82d14831f4 100644
--- a/storage/src/vespa/storage/distributor/CMakeLists.txt
+++ b/storage/src/vespa/storage/distributor/CMakeLists.txt
@@ -3,26 +3,26 @@ vespa_add_library(storage_distributor
SOURCES
activecopy.cpp
blockingoperationstarter.cpp
- bucketdbupdater.cpp
bucket_db_prune_elision.cpp
+ bucket_space_distribution_context.cpp
+ bucketdbupdater.cpp
bucketgctimecalculator.cpp
bucketlistmerger.cpp
- bucket_space_distribution_context.cpp
clusterinformation.cpp
crypto_uuid_generator.cpp
+ distributor.cpp
distributor_bucket_space.cpp
distributor_bucket_space_repo.cpp
- distributor.cpp
distributor_host_info_reporter.cpp
distributor_status.cpp
distributor_stripe.cpp
- distributorcomponent.cpp
+ distributor_stripe_component.cpp
distributormessagesender.cpp
distributormetricsset.cpp
externaloperationhandler.cpp
+ ideal_service_layer_nodes_bundle.cpp
idealstatemanager.cpp
idealstatemetricsset.cpp
- ideal_service_layer_nodes_bundle.cpp
messagetracker.cpp
nodeinfo.cpp
operation_routing_snapshot.cpp
@@ -31,8 +31,8 @@ vespa_add_library(storage_distributor
operationtargetresolver.cpp
operationtargetresolverimpl.cpp
ownership_transfer_safe_time_point_calculator.cpp
- pendingclusterstate.cpp
pending_bucket_space_db_transition.cpp
+ pendingclusterstate.cpp
pendingmessagetracker.cpp
persistence_operation_metric_set.cpp
persistencemessagetracker.cpp
diff --git a/storage/src/vespa/storage/distributor/bucketdbupdater.h b/storage/src/vespa/storage/distributor/bucketdbupdater.h
index 13a6235a4e5..375a5cee4e7 100644
--- a/storage/src/vespa/storage/distributor/bucketdbupdater.h
+++ b/storage/src/vespa/storage/distributor/bucketdbupdater.h
@@ -2,19 +2,19 @@
#pragma once
#include "bucketlistmerger.h"
-#include "messageguard.h"
-#include "distributorcomponent.h"
+#include "distributor_stripe_component.h"
#include "distributormessagesender.h"
-#include "pendingclusterstate.h"
+#include "messageguard.h"
#include "operation_routing_snapshot.h"
#include "outdated_nodes_map.h"
+#include "pendingclusterstate.h"
#include <vespa/document/bucket/bucket.h>
-#include <vespa/storageapi/message/bucket.h>
-#include <vespa/vdslib/state/clusterstate.h>
#include <vespa/storage/common/storagelink.h>
+#include <vespa/storageapi/message/bucket.h>
+#include <vespa/storageapi/messageapi/messagehandler.h>
#include <vespa/storageframework/generic/clock/timer.h>
#include <vespa/storageframework/generic/status/statusreporter.h>
-#include <vespa/storageapi/messageapi/messagehandler.h>
+#include <vespa/vdslib/state/clusterstate.h>
#include <atomic>
#include <list>
#include <mutex>
@@ -239,7 +239,7 @@ private:
mutable bool _cachedOwned;
};
- DistributorComponent _distributorComponent;
+ DistributorStripeComponent _distributorComponent;
const DistributorNodeContext& _node_ctx;
DistributorOperationContext& _op_ctx;
DistributorStripeInterface& _distributor_interface;
diff --git a/storage/src/vespa/storage/distributor/distributor.h b/storage/src/vespa/storage/distributor/distributor.h
index 82e1ceb16f6..261343b83fd 100644
--- a/storage/src/vespa/storage/distributor/distributor.h
+++ b/storage/src/vespa/storage/distributor/distributor.h
@@ -15,7 +15,7 @@
#include <vespa/storage/common/doneinitializehandler.h>
#include <vespa/storage/common/messagesender.h>
#include <vespa/storage/distributor/bucketdb/bucketdbmetricupdater.h>
-#include <vespa/storage/distributor/distributorcomponent.h>
+#include <vespa/storage/distributor/distributor_stripe_component.h>
#include <vespa/storage/distributor/maintenance/maintenancescheduler.h>
#include <vespa/storageapi/message/state.h>
#include <vespa/storageframework/generic/metric/metricupdatehook.h>
@@ -155,7 +155,7 @@ public:
DistributorBucketSpaceRepo& getReadOnlyBucketSpaceRepo() noexcept;
const DistributorBucketSpaceRepo& getReadyOnlyBucketSpaceRepo() const noexcept;
- storage::distributor::DistributorComponent& distributor_component() noexcept;
+ storage::distributor::DistributorStripeComponent& distributor_component() noexcept;
void sendCommand(const std::shared_ptr<api::StorageCommand>&) override;
void sendReply(const std::shared_ptr<api::StorageReply>&) override;
@@ -243,7 +243,7 @@ private:
// during cluster state transitions. Bucket set does not overlap that of _bucketSpaceRepo
// and the DBs are empty during non-transition phases.
std::unique_ptr<DistributorBucketSpaceRepo> _readOnlyBucketSpaceRepo;
- storage::distributor::DistributorComponent _component;
+ storage::distributor::DistributorStripeComponent _component;
StatusReporterDelegate _distributorStatusDelegate;
diff --git a/storage/src/vespa/storage/distributor/distributor_stripe.cpp b/storage/src/vespa/storage/distributor/distributor_stripe.cpp
index 2b020c43c4a..0a3befbbf5c 100644
--- a/storage/src/vespa/storage/distributor/distributor_stripe.cpp
+++ b/storage/src/vespa/storage/distributor/distributor_stripe.cpp
@@ -28,7 +28,7 @@ using namespace std::chrono_literals;
namespace storage::distributor {
/* TODO STRIPE
- * - need a DistributorComponent per stripe
+ * - need a DistributorStripeComponent per stripe
* - or better, remove entirely!
* - probably also DistributorStripeInterface since it's used to send
* - metrics aggregation
diff --git a/storage/src/vespa/storage/distributor/distributor_stripe.h b/storage/src/vespa/storage/distributor/distributor_stripe.h
index ac2193877a5..c6ada1f1ad7 100644
--- a/storage/src/vespa/storage/distributor/distributor_stripe.h
+++ b/storage/src/vespa/storage/distributor/distributor_stripe.h
@@ -15,7 +15,7 @@
#include <vespa/storage/common/doneinitializehandler.h>
#include <vespa/storage/common/messagesender.h>
#include <vespa/storage/distributor/bucketdb/bucketdbmetricupdater.h>
-#include <vespa/storage/distributor/distributorcomponent.h>
+#include <vespa/storage/distributor/distributor_stripe_component.h>
#include <vespa/storage/distributor/maintenance/maintenancescheduler.h>
#include <vespa/storageapi/message/state.h>
#include <vespa/storageframework/generic/metric/metricupdatehook.h>
@@ -284,7 +284,7 @@ private:
// during cluster state transitions. Bucket set does not overlap that of _bucketSpaceRepo
// and the DBs are empty during non-transition phases.
std::unique_ptr<DistributorBucketSpaceRepo> _readOnlyBucketSpaceRepo;
- storage::distributor::DistributorComponent _component;
+ storage::distributor::DistributorStripeComponent _component;
DistributorMetricSet& _metrics;
OperationOwner _operationOwner;
diff --git a/storage/src/vespa/storage/distributor/distributorcomponent.cpp b/storage/src/vespa/storage/distributor/distributor_stripe_component.cpp
index 4c170791fa2..a153b1d90c1 100644
--- a/storage/src/vespa/storage/distributor/distributorcomponent.cpp
+++ b/storage/src/vespa/storage/distributor/distributor_stripe_component.cpp
@@ -1,5 +1,5 @@
// Copyright 2017 Yahoo Holdings. Licensed under the terms of the Apache 2.0 license. See LICENSE in the project root.
-#include "distributorcomponent.h"
+#include "distributor_stripe_component.h"
#include "distributor_bucket_space_repo.h"
#include "distributor_bucket_space.h"
#include "pendingmessagetracker.h"
@@ -14,7 +14,7 @@ using document::BucketSpace;
namespace storage::distributor {
-DistributorComponent::DistributorComponent(
+DistributorStripeComponent::DistributorStripeComponent(
DistributorStripeInterface& distributor,
DistributorBucketSpaceRepo& bucketSpaceRepo,
DistributorBucketSpaceRepo& readOnlyBucketSpaceRepo,
@@ -27,34 +27,34 @@ DistributorComponent::DistributorComponent(
{
}
-DistributorComponent::~DistributorComponent() = default;
+DistributorStripeComponent::~DistributorStripeComponent() = default;
void
-DistributorComponent::sendDown(const api::StorageMessage::SP& msg)
+DistributorStripeComponent::sendDown(const api::StorageMessage::SP& msg)
{
_distributor.getMessageSender().sendDown(msg);
}
void
-DistributorComponent::sendUp(const api::StorageMessage::SP& msg)
+DistributorStripeComponent::sendUp(const api::StorageMessage::SP& msg)
{
_distributor.getMessageSender().sendUp(msg);
}
const lib::ClusterStateBundle&
-DistributorComponent::getClusterStateBundle() const
+DistributorStripeComponent::getClusterStateBundle() const
{
return _distributor.getClusterStateBundle();
};
api::StorageMessageAddress
-DistributorComponent::nodeAddress(uint16_t nodeIndex) const
+DistributorStripeComponent::nodeAddress(uint16_t nodeIndex) const
{
return api::StorageMessageAddress::create(cluster_name_ptr(), lib::NodeType::STORAGE, nodeIndex);
}
bool
-DistributorComponent::checkDistribution(api::StorageCommand &cmd, const document::Bucket &bucket)
+DistributorStripeComponent::checkDistribution(api::StorageCommand &cmd, const document::Bucket &bucket)
{
auto &bucket_space(_bucketSpaceRepo.get(bucket.getBucketSpace()));
BucketOwnership bo(bucket_space.check_ownership_in_pending_and_current_state(bucket.getBucketId()));
@@ -74,7 +74,7 @@ DistributorComponent::checkDistribution(api::StorageCommand &cmd, const document
}
void
-DistributorComponent::removeNodesFromDB(const document::Bucket &bucket, const std::vector<uint16_t>& nodes)
+DistributorStripeComponent::removeNodesFromDB(const document::Bucket &bucket, const std::vector<uint16_t>& nodes)
{
auto &bucketSpace(_bucketSpaceRepo.get(bucket.getBucketSpace()));
BucketDatabase::Entry dbentry = bucketSpace.getBucketDatabase().get(bucket.getBucketId());
@@ -104,7 +104,7 @@ DistributorComponent::removeNodesFromDB(const document::Bucket &bucket, const st
}
void
-DistributorComponent::enumerateUnavailableNodes(
+DistributorStripeComponent::enumerateUnavailableNodes(
std::vector<uint16_t>& unavailableNodes,
const lib::ClusterState& s,
const document::Bucket& bucket,
@@ -184,7 +184,7 @@ UpdateBucketDatabaseProcessor::process_entry(BucketDatabase::Entry &entry) const
}
void
-DistributorComponent::updateBucketDatabase(
+DistributorStripeComponent::updateBucketDatabase(
const document::Bucket &bucket,
const std::vector<BucketCopy>& changedNodes,
uint32_t updateFlags)
@@ -231,13 +231,13 @@ DistributorComponent::updateBucketDatabase(
}
void
-DistributorComponent::recheckBucketInfo(uint16_t nodeIdx, const document::Bucket &bucket)
+DistributorStripeComponent::recheckBucketInfo(uint16_t nodeIdx, const document::Bucket &bucket)
{
_distributor.recheckBucketInfo(nodeIdx, bucket);
}
document::BucketId
-DistributorComponent::getBucketId(const document::DocumentId& docId) const
+DistributorStripeComponent::getBucketId(const document::DocumentId& docId) const
{
document::BucketId id(getBucketIdFactory().getBucketId(docId));
@@ -246,7 +246,7 @@ DistributorComponent::getBucketId(const document::DocumentId& docId) const
}
bool
-DistributorComponent::storageNodeIsUp(document::BucketSpace bucketSpace, uint32_t nodeIndex) const
+DistributorStripeComponent::storageNodeIsUp(document::BucketSpace bucketSpace, uint32_t nodeIndex) const
{
const lib::NodeState& ns = getClusterStateBundle().getDerivedClusterState(bucketSpace)->getNodeState(
lib::Node(lib::NodeType::STORAGE, nodeIndex));
@@ -255,7 +255,7 @@ DistributorComponent::storageNodeIsUp(document::BucketSpace bucketSpace, uint32_
}
document::BucketId
-DistributorComponent::getSibling(const document::BucketId& bid) const {
+DistributorStripeComponent::getSibling(const document::BucketId& bid) const {
document::BucketId zeroBucket;
document::BucketId oneBucket;
@@ -282,7 +282,7 @@ DistributorComponent::getSibling(const document::BucketId& bid) const {
};
BucketDatabase::Entry
-DistributorComponent::createAppropriateBucket(const document::Bucket &bucket)
+DistributorStripeComponent::createAppropriateBucket(const document::Bucket &bucket)
{
auto &bucketSpace(_bucketSpaceRepo.get(bucket.getBucketSpace()));
return bucketSpace.getBucketDatabase().createAppropriateBucket(
@@ -291,16 +291,16 @@ DistributorComponent::createAppropriateBucket(const document::Bucket &bucket)
}
bool
-DistributorComponent::has_pending_message(uint16_t node_index,
- const document::Bucket& bucket,
- uint32_t message_type) const
+DistributorStripeComponent::has_pending_message(uint16_t node_index,
+ const document::Bucket& bucket,
+ uint32_t message_type) const
{
const auto& sender = static_cast<const DistributorMessageSender&>(getDistributor());
return sender.getPendingMessageTracker().hasPendingMessage(node_index, bucket, message_type);
}
std::unique_ptr<document::select::Node>
-DistributorComponent::parse_selection(const vespalib::string& selection) const
+DistributorStripeComponent::parse_selection(const vespalib::string& selection) const
{
document::select::Parser parser(*getTypeRepo()->documentTypeRepo, getBucketIdFactory());
return parser.parse(selection);
diff --git a/storage/src/vespa/storage/distributor/distributorcomponent.h b/storage/src/vespa/storage/distributor/distributor_stripe_component.h
index b4aa27a781b..994af741e73 100644
--- a/storage/src/vespa/storage/distributor/distributorcomponent.h
+++ b/storage/src/vespa/storage/distributor/distributor_stripe_component.h
@@ -26,20 +26,21 @@ struct DatabaseUpdate {
/**
* Takes care of subscribing to document manager config and
* making those values available to other subcomponents.
+ * TODO STRIPE update class comment.
*/
-class DistributorComponent : public storage::DistributorComponent,
- public DistributorNodeContext,
- public DistributorOperationContext,
- public DocumentSelectionParser
+class DistributorStripeComponent : public storage::DistributorComponent,
+ public DistributorNodeContext,
+ public DistributorOperationContext,
+ public DocumentSelectionParser
{
public:
- DistributorComponent(DistributorStripeInterface& distributor,
- DistributorBucketSpaceRepo& bucketSpaceRepo,
- DistributorBucketSpaceRepo& readOnlyBucketSpaceRepo,
- DistributorComponentRegister& compReg,
- const std::string& name);
+ DistributorStripeComponent(DistributorStripeInterface& distributor,
+ DistributorBucketSpaceRepo& bucketSpaceRepo,
+ DistributorBucketSpaceRepo& readOnlyBucketSpaceRepo,
+ DistributorComponentRegister& compReg,
+ const std::string& name);
- ~DistributorComponent() override;
+ ~DistributorStripeComponent() override;
/**
* Returns a reference to the current cluster state bundle. Valid until the
diff --git a/storage/src/vespa/storage/distributor/externaloperationhandler.h b/storage/src/vespa/storage/distributor/externaloperationhandler.h
index 3f4a6674761..6205321ce84 100644
--- a/storage/src/vespa/storage/distributor/externaloperationhandler.h
+++ b/storage/src/vespa/storage/distributor/externaloperationhandler.h
@@ -3,7 +3,7 @@
#include <vespa/document/bucket/bucketid.h>
#include <vespa/document/bucket/bucketidfactory.h>
-#include <vespa/storage/distributor/distributorcomponent.h>
+#include <vespa/storage/distributor/distributor_stripe_component.h>
#include <vespa/storageapi/messageapi/messagehandler.h>
#include <atomic>
#include <chrono>
diff --git a/storage/src/vespa/storage/distributor/idealstatemanager.h b/storage/src/vespa/storage/distributor/idealstatemanager.h
index f4c9a009e7d..2665d7938ed 100644
--- a/storage/src/vespa/storage/distributor/idealstatemanager.h
+++ b/storage/src/vespa/storage/distributor/idealstatemanager.h
@@ -1,7 +1,7 @@
// Copyright 2017 Yahoo Holdings. Licensed under the terms of the Apache 2.0 license. See LICENSE in the project root.
#pragma once
-#include "distributorcomponent.h"
+#include "distributor_stripe_component.h"
#include "statechecker.h"
#include <vespa/storage/distributor/maintenance/maintenanceprioritygenerator.h>
#include <vespa/storage/distributor/maintenance/maintenanceoperationgenerator.h>
@@ -77,7 +77,7 @@ public:
getBucketStatus(out);
}
- DistributorComponent& getDistributorComponent() { return _distributorComponent; }
+ DistributorStripeComponent& getDistributorComponent() { return _distributorComponent; }
DistributorBucketSpaceRepo &getBucketSpaceRepo() { return _bucketSpaceRepo; }
const DistributorBucketSpaceRepo &getBucketSpaceRepo() const { return _bucketSpaceRepo; }
@@ -100,8 +100,8 @@ private:
std::vector<StateChecker::SP> _stateCheckers;
SplitBucketStateChecker* _splitBucketStateChecker;
- DistributorComponent _distributorComponent;
- DistributorBucketSpaceRepo &_bucketSpaceRepo;
+ DistributorStripeComponent _distributorComponent;
+ DistributorBucketSpaceRepo& _bucketSpaceRepo;
mutable bool _has_logged_phantom_replica_warning;
bool iAmUp() const;
diff --git a/storage/src/vespa/storage/distributor/operations/external/statbucketoperation.cpp b/storage/src/vespa/storage/distributor/operations/external/statbucketoperation.cpp
index ec8e4539ad1..d0fdd539b72 100644
--- a/storage/src/vespa/storage/distributor/operations/external/statbucketoperation.cpp
+++ b/storage/src/vespa/storage/distributor/operations/external/statbucketoperation.cpp
@@ -1,6 +1,6 @@
// Copyright 2017 Yahoo Holdings. Licensed under the terms of the Apache 2.0 license. See LICENSE in the project root.
#include "statbucketoperation.h"
-#include <vespa/storage/distributor/distributorcomponent.h>
+#include <vespa/storage/distributor/distributor_stripe_component.h>
#include <vespa/storageapi/message/persistence.h>
#include <vespa/storageapi/message/stat.h>
#include <vespa/storage/distributor/distributor_bucket_space.h>
diff --git a/storage/src/vespa/storage/distributor/persistencemessagetracker.h b/storage/src/vespa/storage/distributor/persistencemessagetracker.h
index 1421b4c2038..87b2d1e8de0 100644
--- a/storage/src/vespa/storage/distributor/persistencemessagetracker.h
+++ b/storage/src/vespa/storage/distributor/persistencemessagetracker.h
@@ -1,8 +1,8 @@
// Copyright 2017 Yahoo Holdings. Licensed under the terms of the Apache 2.0 license. See LICENSE in the project root.
#pragma once
+#include "distributor_stripe_component.h"
#include "distributormetricsset.h"
-#include "distributorcomponent.h"
#include "messagetracker.h"
#include <vespa/storageframework/generic/clock/timer.h>
#include <vespa/storageapi/messageapi/bucketinfocommand.h>
diff --git a/storage/src/vespa/storage/distributor/statechecker.cpp b/storage/src/vespa/storage/distributor/statechecker.cpp
index 22605d56a74..3f143908730 100644
--- a/storage/src/vespa/storage/distributor/statechecker.cpp
+++ b/storage/src/vespa/storage/distributor/statechecker.cpp
@@ -1,7 +1,7 @@
// Copyright 2017 Yahoo Holdings. Licensed under the terms of the Apache 2.0 license. See LICENSE in the project root.
#include "statechecker.h"
-#include "distributorcomponent.h"
#include "distributor_bucket_space.h"
+#include "distributor_stripe_component.h"
#include <vespa/vdslib/distribution/distribution.h>
#include <vespa/vdslib/state/clusterstate.h>
@@ -61,7 +61,7 @@ StateChecker::Result::createStoredResult(
return Result(std::unique_ptr<ResultImpl>(new StoredResultImpl(std::move(operation), MaintenancePriority(priority))));
}
-StateChecker::Context::Context(const DistributorComponent& c,
+StateChecker::Context::Context(const DistributorStripeComponent& c,
const DistributorBucketSpace &distributorBucketSpace,
NodeMaintenanceStatsTracker& statsTracker,
const document::Bucket &bucket_)
diff --git a/storage/src/vespa/storage/distributor/statechecker.h b/storage/src/vespa/storage/distributor/statechecker.h
index 734b44bd7d1..44c45e62ec8 100644
--- a/storage/src/vespa/storage/distributor/statechecker.h
+++ b/storage/src/vespa/storage/distributor/statechecker.h
@@ -17,7 +17,7 @@ namespace storage { class DistributorConfiguration; }
namespace storage::distributor {
-class DistributorComponent;
+class DistributorStripeComponent;
class DistributorBucketSpace;
class NodeMaintenanceStatsTracker;
@@ -44,7 +44,7 @@ public:
*/
struct Context
{
- Context(const DistributorComponent&,
+ Context(const DistributorStripeComponent&,
const DistributorBucketSpace &distributorBucketSpace,
NodeMaintenanceStatsTracker&,
const document::Bucket &bucket_);
@@ -76,7 +76,7 @@ public:
std::vector<uint16_t> idealState;
std::unordered_set<uint16_t> unorderedIdealState;
- const DistributorComponent& component;
+ const DistributorStripeComponent& component;
const BucketDatabase& db;
NodeMaintenanceStatsTracker& stats;
diff --git a/storage/src/vespa/storage/distributor/distributor.cpp b/storage/src/vespa/storage/distributor/distributor.cpp
index eac7219a24d..29af083cf4e 100644
--- a/storage/src/vespa/storage/distributor/distributor.cpp
+++ b/storage/src/vespa/storage/distributor/distributor.cpp
@@ -29,7 +29,7 @@ using namespace std::chrono_literals;
namespace storage::distributor {
/* TODO STRIPE
* - need a DistributorComponent per stripe
* - or better, remove entirely!
* - probably also DistributorStripeInterface since it's used to send
* - metrics aggregation
@@ -52,7 +52,7 @@ Distributor::Distributor(DistributorComponentRegister& compReg,
_messageSender(messageSender),
_stripe(std::make_unique<DistributorStripe>(compReg, *_metrics, node_identity, threadPool, doneInitHandler,
manageActiveBucketCopies, *this)),
// TODO STRIPE remove once DistributorComponent no longer references bucket space repos
_bucketSpaceRepo(std::make_unique<DistributorBucketSpaceRepo>(node_identity.node_index())),
_readOnlyBucketSpaceRepo(std::make_unique<DistributorBucketSpaceRepo>(node_identity.node_index())),
// TODO STRIPE slim down
@@ -117,7 +117,7 @@ Distributor::getReadyOnlyBucketSpaceRepo() const noexcept {
return _stripe->getReadOnlyBucketSpaceRepo();;
}
-storage::distributor::DistributorComponent&
+storage::distributor::DistributorStripeComponent&
Distributor::distributor_component() noexcept {
// TODO STRIPE We need to grab the stripe's component since tests like to access
// these things uncomfortably directly.
@@ -29,7 +29,7 @@ using namespace std::chrono_literals;
namespace storage::distributor {
/* TODO STRIPE
- * - need a DistributorComponent per stripe
+ * - need a DistributorStripeComponent per stripe
* - or better, remove entirely!
* - probably also DistributorStripeInterface since it's used to send
@@ -52,7 +52,7 @@ Distributor::Distributor(DistributorComponentRegister& compReg,
_stripe(std::make_unique<DistributorStripe>(compReg, *_metrics, node_identity, threadPool, doneInitHandler,
manageActiveBucketCopies, *this)),
- // TODO STRIPE remove once DistributorComponent no longer references bucket space repos
+ // TODO STRIPE remove once DistributorStripeComponent no longer references bucket space repos
_bucketSpaceRepo(std::make_unique<DistributorBucketSpaceRepo>(node_identity.node_index())),
_readOnlyBucketSpaceRepo(std::make_unique<DistributorBucketSpaceRepo>(node_identity.node_index())),